betas: Record the Probabilistic Event

Description Usage Arguments Value Examples

View source: R/betas.R

Description

Record the Probabilistic Event

Usage

1
2
betas(case_num = 0, model = model$gibbs, concept, doc, topic_num = 0,
  math = 0, omitted_terms = 0)

Arguments

case_num

The case number

model

The model generated from ldamodel function

concept

The thematic concept (viz. 'school', 'family', 'work')

doc

The document in question

topic_num

The topic number from the reviewed topics list.

math

The number that needs to be subtracted from the beta sum, based on KWIC

ommitted_terms

vocabulary terms rooted from the summary beta values based on human inspection.

Value

An artifact qualifying as the record of the probabilistic event

Examples

1
output <- betas(case_num = 1, model = model, concept = 'work', doc = doc, topic_num = 3, math = 0)

cownr10r/pahl documentation built on May 6, 2019, 6:57 p.m.