corpsum: Summary Statistics

Description Usage Arguments Value Examples

View source: R/corpsum.R

Description

Return the summary statistics on text found in an .xlsx file. This requires the previous essay function to be written like this: doc <- essay(data_dir, file, 1)

Usage

1
corpsum(doc = doc)

Arguments

doc

A character object returned from the essay function

Value

Text number, Token Types, Sentence numbers, and Title. An abbreviated version of summary in quanteda

Examples

1
corpsum(doc)

cownr10r/pahl documentation built on May 6, 2019, 6:57 p.m.