ldamodel: This will return a topics model generated through Gibbs...

Description Usage Arguments Value Examples

View source: R/ldamodel.R

Description

This will return a topics model generated through Gibbs sampling

Usage

1
ldamodel(a = features, b = 0, c = 0)

Arguments

a

An object named 'features' from tm_dfm

b

The kappa number

seed

The seed number

Value

A topic model from "topicmodels" with Gibbs Sampling

Examples

1
mod <- ldamodel(features, 8)

cownr10r/pahl documentation built on May 6, 2019, 6:57 p.m.