Description Usage Arguments Value Examples
Record the Probabilistic Event
1 2 | betas(case_num = 0, model = model$gibbs, concept, doc, topic_num = 0,
math = 0, omitted_terms = 0)
|
case_num |
The case number |
model |
The model generated from ldamodel function |
concept |
The thematic concept (viz. 'school', 'family', 'work') |
doc |
The document in question |
topic_num |
The topic number from the reviewed topics list. |
math |
The number that needs to be subtracted from the beta sum, based on KWIC |
ommitted_terms |
vocabulary terms rooted from the summary beta values based on human inspection. |
An artifact qualifying as the record of the probabilistic event
1 | output <- betas(case_num = 1, model = model, concept = 'work', doc = doc, topic_num = 3, math = 0)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.