Description Usage Arguments Value Examples
Return the summary statistics on text found in an .xlsx file. This requires the previous essay function to be written like this: doc <- essay(data_dir, file, 1)
1 | corpsum(doc = doc)
|
doc |
A character object returned from the essay function |
Text number, Token Types, Sentence numbers, and Title. An abbreviated version of summary in quanteda
1 | corpsum(doc)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.